<!--
https://pypi.org/project/readme-generator/
https://pypi.org/project/python-readme-generator/
-->

[![](https://img.shields.io/badge/OS-MacOS-blue.svg?longCache=True)]()

#### Installation
```bash
$ [sudo] pip install launchd-tag
```

#### Requirements
```bash
$ brew install tag
```

#### How it works
color|description
-|-
none|running
Gray|not running
Red|non-zero exit status
Orange|not empty stderr (`StandardErrorPath`)

#### Scripts usage
```bash
usage: launchd-tag
```

#### Examples
```bash
$ launchd-tag
```

#### Related projects
+   [`launchd-env` - launchd.plist environment variables](https://pypi.org/project/launchd-env/)
+   [`launchd-exec` - execute script via launchd](https://pypi.org/project/launchd-exec/)
+   [`launchd-generator` - launchd.plist generator](https://pypi.org/project/launchd-generator/)
+   [`launchd-logs` - launchd.plist logs](https://pypi.org/project/launchd-logs/)
+   [`launchd-tag` - LaunchAgents Finder tags](https://pypi.org/project/launchd-tag/)

#### Links
+   [github.com/jdberry/tag](https://github.com/jdberry/tag)

<p align="center">
    <a href="https://pypi.org/project/python-readme-generator/">python-readme-generator</a>
</p>